#
# spec file for package udisks2
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soversion 0
%define libblockdev_version 3.0

Name:           udisks2
Version:        2.10.1
Release:        2.1
Summary:        Disk Manager
License:        GPL-2.0-or-later AND LGPL-2.0-or-later
Group:          System/Daemons
URL:            https://github.com/storaged-project/udisks
Source0:        %{url}/releases/download/udisks-%{version}/udisks-%{version}.tar.bz2

# Upstream First - Policy:
# Never add any patches to this package without the upstream commit id
# in the patch. Any patches added here without a very good reason to make
# an exception will be silently removed with the next version update.

Patch0:         harden_udisks2.service.patch

BuildRequires:  chrpath
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  gobject-introspection-devel >= 0.6.2
BuildRequires:  libacl-devel
BuildRequires:  libblockdev-crypto-devel >= %{libblockdev_version}
BuildRequires:  libblockdev-fs-devel >= %{libblockdev_version}
BuildRequires:  libblockdev-loop-devel >= %{libblockdev_version}
BuildRequires:  libblockdev-mdraid-devel >= %{libblockdev_version}
BuildRequires:  libblockdev-nvme-devel >= %{libblockdev_version}
BuildRequires:  libblockdev-part-devel >= %{libblockdev_version}
BuildRequires:  libblockdev-swap-devel >= %{libblockdev_version}
BuildRequires:  lvm2-devel
BuildRequires:  pkgconfig
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(blkid) >= 2.17.0
BuildRequires:  pkgconfig(blockdev) >= 2.19
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.50
BuildRequires:  pkgconfig(glib-2.0) >= 2.50
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gudev-1.0) >= 165
BuildRequires:  pkgconfig(libatasmart) >= 0.17
BuildRequires:  pkgconfig(libsystemd) >= 209
BuildRequires:  pkgconfig(mount) >= 2.30
BuildRequires:  pkgconfig(polkit-agent-1) >= 0.102
BuildRequires:  pkgconfig(polkit-gobject-1) >= 0.102
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(uuid)

Requires:       libudisks2-%{soversion} = %{version}
# For LUKS devices
Requires:       cryptsetup
# Needed to pull in the system bus daemon
Requires:       dbus-1 >= 1.4.0
# For mkfs.vfat
Requires:       dosfstools
# For mkfs.ext3, mkfs.ext3, e2label
Requires:       e2fsprogs
# For ejecting removable disks
Requires:       eject
# sgdisk is called by udisksd to modify the partition tables... thus a needed tool.
Requires:       gptfdisk
# We need at least this version for bugfixes/features etc.
Requires:       libatasmart-utils >= 0.17
Requires:       libblockdev >= %{libblockdev_version}
Requires:       libblockdev-crypto >= %{libblockdev_version}
Requires:       libblockdev-fs >= %{libblockdev_version}
Requires:       libblockdev-loop >= %{libblockdev_version}
Requires:       libblockdev-mdraid >= %{libblockdev_version}
Requires:       libblockdev-nvme >= %{libblockdev_version}
Requires:       libblockdev-part >= %{libblockdev_version}
Requires:       libblockdev-swap >= %{libblockdev_version}
# Needed to pull in the udev daemon
Requires:       udev >= 208
# For mount, umount, mkswap
Requires:       util-linux
# For mkfs.xfs, xfs_admin
Requires:       xfsprogs

Recommends:     libudisks2-%{soversion}_btrfs

# Drop deprecated modules from end users' systems upon system upgrade
Obsoletes:      libudisks2-0_vdo <= 2.9.4
Obsoletes:      libudisks2-0_bcache < 2.10
Obsoletes:      libudisks2-0_zram < 2.10

%description
The Udisks project provides a daemon, tools and libraries to access and
manipulate disks, storage devices and technologies.

%package -n libudisks2-%{soversion}
Summary:        Dynamic library to access the UDisksd daemon
License:        LGPL-2.0-or-later
Group:          System/Libraries

%description -n libudisks2-%{soversion}
This package contains the dynamic library, which provides
access to the UDisksd daemon.

%package -n typelib-1_0-UDisks-2_0
Summary:        Introspection bindings for the UDisks Client Library version 2
License:        LGPL-2.0-or-later
Group:          System/Libraries

%description -n typelib-1_0-UDisks-2_0
UDisks provides a daemon, D-Bus API and command line tools
for managing disks and storage devices.

This package provides the GObject Introspection bindings for
the UDisks client library.

%package -n libudisks2-%{soversion}-devel
Summary:        Development files for UDisks
License:        LGPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libudisks2-%{soversion} >= %{version}

%description -n libudisks2-%{soversion}-devel
This package contains the development files for the library libUDisks2, a
dynamic library, which provides access to the UDisksd daemon.

%package docs
Summary:        Developer documentation for %{name}
BuildArch:      noarch

%description docs
This package contains developer documentation for %{name}.

%package -n libudisks2-%{soversion}_btrfs
Summary:        UDisks module for btrfs
License:        LGPL-2.0-or-later
Group:          System/Libraries
BuildRequires:  libblockdev-btrfs-devel >= %{libblockdev_version}
Requires:       libblockdev-btrfs >= %{libblockdev_version}
Requires:       libudisks2-%{soversion} >= %{version}

%description -n libudisks2-%{soversion}_btrfs
This package contains the UDisks module for btrfs support.

%package -n libudisks2-%{soversion}_lsm
Summary:        UDisks module for LSM
License:        LGPL-2.0-or-later
Group:          System/Libraries
BuildRequires:  pkgconfig(libconfig) >= 1.3.2
BuildRequires:  pkgconfig(libstoragemgmt) >= 1.3.0
Requires:       libstoragemgmt >= 1.3.0
Requires:       libudisks2-%{soversion} >= %{version}

%description -n libudisks2-%{soversion}_lsm
This package contains the UDisks module for LSM support.

%package -n libudisks2-%{soversion}_lvm2
Summary:        UDisks module for LVM2
License:        LGPL-2.0-or-later
Group:          System/Libraries
BuildRequires:  libblockdev-lvm-devel >= %{libblockdev_version}
Requires:       libblockdev-lvm >= %{libblockdev_version}
Requires:       libudisks2-%{soversion} >= %{version}
Requires:       lvm2

%description -n libudisks2-%{soversion}_lvm2
This package contains the UDisks module for LVM2 support.

%package bash-completion
Summary:        Bash Completion for udisksctl
BuildRequires:  bash-completion
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for the udisksctl command.

%package zsh-completion
Summary:        Zsh Completion for udisksctl
BuildRequires:  zsh
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for the udisksctl command.

%lang_package

%prep
%autosetup -p1 -n udisks-%{version}

%build
%configure \
	--disable-static \
	--disable-gtk-doc \
	--docdir=%{_docdir}/%{name} \
	--enable-btrfs \
	--enable-lsm \
	--enable-lvm2 \
	%{nil}
%make_build

%install
%make_install
find %{buildroot} -name "*.la" -print -type f -delete
chrpath --delete %{buildroot}/%{_sbindir}/umount.udisks2
chrpath --delete %{buildroot}/%{_bindir}/udisksctl
chrpath --delete %{buildroot}/%{_libexecdir}/udisks2/udisksd
%find_lang udisks2

%if 0%{?suse_version} < 1600
# Create udisks2 rclink
mkdir -p %{buildroot}/%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}/%{_sbindir}/rc%{name}
%endif

# Move example config file to docs
mkdir -p %{buildroot}%{_docdir}/%{name}
mv -v %{buildroot}%{_sysconfdir}/udisks2/mount_options.conf.example \
    %{buildroot}%{_docdir}/%{name}/mount_options.conf.example

%post -n libudisks2-%{soversion} -p /sbin/ldconfig
%postun -n libudisks2-%{soversion} -p /sbin/ldconfig

%pre -n %{name}
%service_add_pre udisks2.service

%post -n %{name}
%{?udev_rules_update:%udev_rules_update}
%service_add_post udisks2.service
%tmpfiles_create %{_tmpfilesdir}/udisks2.conf

%preun -n %{name}
%service_del_preun udisks2.service

%postun -n %{name}
%service_del_postun udisks2.service

%files
%doc AUTHORS NEWS
%{_bindir}/udisksctl
%{_datadir}/dbus-1/system.d/org.freedesktop.UDisks2.conf
%dir %{_sysconfdir}/udisks2
%dir %{_sysconfdir}/udisks2/modules.conf.d
%config %{_sysconfdir}/udisks2/udisks2.conf
%doc %{_docdir}/%{name}/mount_options.conf.example
%{_tmpfilesdir}/udisks2.conf
%ghost %{_rundir}/media
%{_unitdir}/udisks2.service
%dir %{_udevrulesdir}
%{_udevrulesdir}/80-udisks2.rules
%if 0%{?suse_version} < 1600
%{_sbindir}/rc%{name}
%endif
%{_sbindir}/umount.udisks2
%dir %{_libexecdir}/udisks2
%{_libexecdir}/udisks2/udisksd
%{_mandir}/man1/udisksctl.1%{?ext_man}
%{_mandir}/man5/udisks2.conf.5%{?ext_man}
%{_mandir}/man8/udisksd.8%{?ext_man}
%{_mandir}/man8/udisks.8%{?ext_man}
%{_mandir}/man8/umount.udisks2.8%{?ext_man}
%{_datadir}/polkit-1/actions/org.freedesktop.UDisks2.policy
%{_datadir}/dbus-1/system-services/org.freedesktop.UDisks2.service
# Permissions for local state data are 0700 to avoid leaking information
# about e.g. mounts to unprivileged users
%attr(0700,root,root) %dir %{_localstatedir}/lib/udisks2

%files -n libudisks2-%{soversion}
%license COPYING
%{_libdir}/libudisks2.so.*

%files -n typelib-1_0-UDisks-2_0
%{_libdir}/girepository-1.0/UDisks-2.0.typelib

%files -n libudisks2-%{soversion}-devel
%doc HACKING README.md
%{_libdir}/libudisks2.so
%dir %{_includedir}/udisks2
%dir %{_includedir}/udisks2/udisks
%{_includedir}/udisks2/udisks/*.h
%{_libdir}/pkgconfig/udisks2.pc
%{_libdir}/pkgconfig/udisks2-btrfs.pc
%{_libdir}/pkgconfig/udisks2-lsm.pc
%{_libdir}/pkgconfig/udisks2-lvm2.pc
%{_datadir}/gir-1.0/UDisks-2.0.gir

%files docs
%doc %{_datadir}/gtk-doc/html/udisks2/

%files -n libudisks2-%{soversion}_btrfs
%dir %{_libdir}/udisks2
%dir %{_libdir}/udisks2/modules
%{_libdir}/udisks2/modules/libudisks2_btrfs.so
%{_datadir}/polkit-1/actions/org.freedesktop.UDisks2.btrfs.policy

%files -n libudisks2-%{soversion}_lsm
%dir %{_sysconfdir}/udisks2/modules.conf.d
%attr(0600,root,root) %config %{_sysconfdir}/udisks2/modules.conf.d/udisks2_lsm.conf
%dir %{_libdir}/udisks2
%dir %{_libdir}/udisks2/modules
%{_libdir}/udisks2/modules/libudisks2_lsm.so
%{_datadir}/polkit-1/actions/org.freedesktop.UDisks2.lsm.policy
%{_mandir}/man5/udisks2_lsm.conf.5%{?ext_man}

%files -n libudisks2-%{soversion}_lvm2
%dir %{_libdir}/udisks2
%dir %{_libdir}/udisks2/modules
%{_libdir}/udisks2/modules/libudisks2_lvm2.so
%{_datadir}/polkit-1/actions/org.freedesktop.UDisks2.lvm2.policy

%files bash-completion
%{_datadir}/bash-completion/completions/udisksctl

%files zsh-completion
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_udisks2

%files lang -f udisks2.lang

%changelog
* Wed Jan 22 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Drop rcFOO symlinks for CODE16 (PED-266).
* Wed May 22 2024 Thomas Blume <Thomas.Blume@suse.com>
- update to version 2.10.1
  - Update Ukrainian translation
  - tests: Wipe used devices for LVM2 RAID tests
  - tests: Settle down before checking the LVM RAID MissingPhysicalVolumes property
  - tests: Rescan vdevs after lvm raid tests
  - Update German translation
  - tests: Mark UDF fstab filesystem tests as unstable
  - tests: Add offline and online filesystem grow tests
  - doc: Clarify the Filesystem.Size property presence
  - udiskslinuxfilesystem: Force native tools for mounted XFS fs size retrieval
  - udiskslinuxfilesystem: Refactor internal whitelists
  - tests: Fix Python class invocation in nvme tests
  - udisksctl: Add "--no-partition-scan" option for "loop-setup" command
  - tests: Fix regex escaping
  - integration-test: Fix invalid escaping
  - tests: Mark LVM RAID tests as unstable
  - tests: Fix LSM drive objects crawl
  - iscsi: Fix login on firmware-discovered nodes
  - udiskslinuxmanager: Properly handle disabled modules
  - tests: Replace deprecated unittest assert calls
  - udisksctl: Guard object lookup
  - Update ka.po
  - udiskslinuxloop: Avoid warnings on empty loop devices
  - Update Polish translation
  - Limit getting filesystem size only to Ext and XFS
  - build: Check for gobject-introspection m4 macro presence
  - tests: start the polkitd mock with the corresponding user if it exists
  - Drop merged upstream patches:
    0001-doc-Clarify-the-Filesystem.Size-property-presence.patch
    0001-udiskslinuxfilesystem-Force-native-tools-for-mounted.patch
    0001-udiskslinuxfilesystem-Refactor-internal-whitelists.patch
    0001-tests-Mark-UDF-fstab-filesystem-tests-as-unstable.patch
    0001-tests-Add-offline-and-online-filesystem-grow-tests.patch
* Wed Oct 11 2023 Thomas Blume <thomas.blume@suse.com>
- fix mount failure on ntfs formatted usb disks (bsc#1216055)
  * add:
    0001-doc-Clarify-the-Filesystem.Size-property-presence.patch
    0001-tests-Mark-UDF-fstab-filesystem-tests-as-unstable.patch
    0001-udiskslinuxfilesystem-Refactor-internal-whitelists.patch
    0001-tests-Add-offline-and-online-filesystem-grow-tests.patch
    0001-udiskslinuxfilesystem-Force-native-tools-for-mounted.patch
* Tue Aug 29 2023 Luciano Santos <luc14n0@opensuse.org>
- Add Obsoletes tags for libudisks2-0_bcache and libudisks2-0_zram
  modules, dropped on latest version bump, so they get removed from
  end users' systems upon system upgrade.
- Drop unnecessary/discouraged %%{?systemd_requires} from spec file.
* Wed Aug 16 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 2.10.0:
  + This release brings large number of internal changes, while
    keeping the promise of API stability. This development cycle
    was mostly driven by libblockdev 3.0 API overhaul.
  + Partitioning was ported to libfdisk.
  + The kbd and vdo libblockdev plugins were removed and so were
    zram, bcache and vdo udisks modules.
  + Definition of supported filesystems was moved to libblockdev
    and filesystem operations were unified.
  + Native NVMe support has been added through libnvme.
  + Syntax of configurable mount options was extended to separate
    filesystem signature and filesystem driver used for mounting.
  + A number of workarounds was placed around the
    org.freedesktop.UDisks2.Filesystem.Size property value
    retrieval to avoid excessive I/O traffic whenever possible.
  + Bash and Zsh completion enhancements.
  + lvm2 module uevent handling improvements.
  + ATA Secure Erase is now allowed only on top-level block
    objects.
  + Extra iSCSI node parameters are now honoured properly.
  + FIPS mode fixes.
  + Added support for resolving devices by PARTLABEL and PARTUUID.
  + Full support for setting filesystem and partition UUIDs.
  + Dynamic mountpoint name sanitization and ACL fixes.
  + Added support for LVM2 RAID.
  + UUID of Bitlocker volumes is now properly exposed.
  + Added an option to force/avoid creation of mdraid write-intent
    bitmap.
  + Updated translations.
- Drop default_luks_encryption macro definition. It's no longer
  needed as upstream defaults to LUKS2 now.
- Drop bcache, vdo and zram sub-packages, following upstream
  changes, and libblockdev-kbd(-devel) BuildRequires/Requires.
- Drop bogus build requirement on libblockdev-lvm-dbus-devel, and
  move libblockdev-lvm-devel BuildRequires to the lvm2 module
  sub-package.
- Move libconfig and libstoragemgmt pkgconfig() BuildRequires to
  the lsm module sub-package, and libblockdev-btrfs-devel
  BuildRequires to the btrfs modules sub-package, which is where
  they belong.
- Add libblockdev-nvme-devel BuildRequires and libblockdev-nvme
  Requires as new required dependencies.
- Drop harden_udisks2-zram-setup@.service.patch: It's unneeded now
  that the zram module has been deprecated.
- Drop merged upstream patches:
  0001-udisksata-Move-the-low-level-PM-state-call.patch,
  0001-udiskslinuxfilesystem-Make-the-size-property-retriev.patch,
  0001-udiskslinuxmountoptions-Do-not-free-static-daemon-re.patch,
  0001-udiskslinuxprovider-Only-update-related-objects-on-u.patch.
- Split Bash and Zsh (new to this release) completion scripts to
  sub-packages of their own.
- Amend GPL-2.0-or-later License tags to LGPL-2.0-or-later for the
  btrfs, lvm2 and lsm UDisks modules sub-packages. This correction
  is based on what's explicitly stated on the source code from
  UDisks modules' folders under the modules/ top-level directory.
* Tue Nov 22 2022 Thomas Blume <thomas.blume@suse.com>
- avoid wakening spun-down disks on unrelated events (bsc#1120608)
  * add:
    0001-udisksata-Move-the-low-level-PM-state-call.patch
    0001-udiskslinuxfilesystem-Make-the-size-property-retriev.patch
    0001-udiskslinuxprovider-Only-update-related-objects-on-u.patch
* Wed Nov 16 2022 Thomas Blume <thomas.blume@suse.com>
- fix crash during shutdown (bsc#1205371)
  * add:
    0001-udiskslinuxmountoptions-Do-not-free-static-daemon-re.patch
* Fri May 20 2022 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_udisks2-zram-setup@.service.patch
  * harden_udisks2.service.patch
* Mon Jan 31 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Drop gtk-doc BuildRequires, and pass disable-gtk-doc to
  configure, the included gtk-docs are fine, we do not need to
  build them ourselves.
* Thu Jan 27 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Stop packaging libudisks_vdo standalone module, it is deprecated.
  Do this via passing explicit disable-vdo to configure and
  dropping libblockdev-vdo-devel BuildRequires. Add a
  libudisks2_0_vdo Obsoletes to ease updates.
- No longer remove upstream config files, we want to be able to
  load modules on demand. Note that we move an example file to docs
  to keep sysconfdir clean of non-conf files.
- Add a default_luks_encryption define, and set it to luks2, sed
  this macro into source, future versions of udisks will not need
  this, as upstream moves to luks2 by default.
- Ghost a dir/file created by us.
- Split out API docs into separate docs sub-package.
* Wed Nov 17 2021 Luciano Santos <luc14n0@linuxmail.org>
- Update to version 2.9.4:
  + Many fixes, improvements, and additions to the code.
  + Mount options:
  - Always use errors=remount-ro for ext filesystems;
  - Add ntfs3 kernel driver options.
  + Build: Remove warnings unknown to clang.
  + Tests: Adapt to clang differences when causing a segfault.
- Changes from version 2.9.3:
  + Many fixes, improvements, and additions to the code and test.
- Add "%%tmpfiles_create %%{_tmpfilesdir}/udisks2.conf" call in %%post
  section to make sure /run/media will be created right after the
  instalation of udisks2.
* Fri Feb 12 2021 Dirk Müller <dmueller@suse.com>
- update to 2.9.2:
  * udiskslinuxblock: Survive a missing /etc/crypttab
  * lvm2: Fix leaking BDLVMVDOPooldata
  * tests: Test modules that are actually enabled during build
  * build: Exclude VDO module from distcheck build
  * udisksfstabentry: Add udisks_fstab_entry_has_opt()
  * udiskslinuxblock: Reflect fstab "noauto" mount option in
    HintAuto
  * udiskslinuxblock: Update hints after fstab change
  * tests: Add tests for Block hints
  * udiskslinuxfilesystemhelpers: Make TakeOwnership() race free
  * tests: Extend filesystem test_take_ownership tests with
    symlinks
  * mount options: Allow 'nosymfollow' mount option for
    unprivileged mounts
  * udisksstate: Silence the block device busy messages on cleanup
    lock
  * udev: Distinguish mmcblk-class device types
  * udev: Propagate mmcblk disk attributes to mmcblk_boot devices
  * udiskslinuxdrive: Tweak the 'removable'/'ejectable' hints for
    mmcblk-class devices
  * udiskslinuxblock: Tweak the hints for mmcblk-class devices
  * udisksdaemonutil: Refactor udisks_daemon_util_trigger_uevent()
    out of UDisksLinuxBlockObject
  * udiskslinuxmanager: Trigger uevent after loop device setup
  * tests: Remove scsi_debug serial number checks
  * tests: Skip zram tests if zram module is already loaded
  * treewide: Fix typos
  * AUTHORS: Add tbzatek as the maintainer
  * tests: Do not use nilfs2 as an example of non-resizable FS
  * Memory leak fixes
  * doc: Update config file path
- Drop udisks2-Fix-memory-leaks.patch, and
  udisks2-lvm2-Fix-leaking-BDLVMVDOPooldata.patch (upstream).
* Sat Dec 19 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add upstream bugfix patches:
  + udisks2-Fix-memory-leaks.patch
  + udisks2-lvm2-Fix-leaking-BDLVMVDOPooldata.patch
* Sun Sep  6 2020 Milan Savić <milsav92@outlook.com>
- Update to version 2.9.1:
  + This is mostly a bugfix release, notable changes include:
  - active modules are now tracked in a daemon state file and
    are automatically reloaded on next startup in case of
    previous unclean daemon shutdown
  - further improvements in object property updates while
    handling method calls
  - zram module fixes:
    + compatibility improvements with existing zram generators
    and toolkits
    + the zram-setup@.service systemd unit has been renamed to
    udisks2-zram-setup@.service
    + related udev rules have been separated into
    90-udisks2-zram.rules
    + the zram.conf.d path is now configurable and defaults to
    /usr/lib/zram.conf.d
- Update to version 2.9.0:
  + This 2.9.0 release brings many changes to the daemon core,
    internal modularity and the libudisks2 library.
    No public API has been removed, there is a couple of
    deprecations however.
  + There's a major change in how and when D-Bus object properties
    are updated. As a general rule when a method call returns
    affected objects should now have their properties updated by
    that moment. This is an ongoing task and while majority of the
    daemon API has been covered, there are pending issues in some
    of the modules.
  + Configurable mount options is a new big feature for this
    release, allowing sysadmins to re-define default mount options
    for each filesystem type. Extensive documentation is available
    at http://storaged.org/doc/udisks2-api/latest/mount_options.html
  + Internal module API has been reworked, modules should now be
    enabled separately via the new EnableModule() call that also
    reports initialization failures.
    The old org.freedesktop.UDisks2.Manager.EnableModules() call
    has been deprecated.
  + Additional feature highlights:
  - building the daemon can now be disabled via configure switch,
    only libudisks2 will be built
  - removed the systemd mount cleanup service, mount state is now
    tracked separately for persistent and non-persistent mount
    points and cleanup of lingering persistent mount points is
    performed on daemon startup (e.g. on system boot)
  - new LVM-VDO integration, deprecated the standalone VDO module
  - added support for (un)locking BitLocker devices
  - libudisks2 now includes generated GDBus code for compiled-in
    modules, separate pkg-config files are provided as well
* Thu Nov 14 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.8.4:
  + This udisks-2.8.4 release brings couple of bugfixes, docs and
    test fixes and translation updates. With ongoing focus on
    development towards udisks-2.9.0, this is just a small
    maintenance release.
* Thu Sep 19 2019 Ludwig Nussel <lnussel@suse.de>
- Do not recommend lang package. The lang package already has a
  supplements.
* Tue Jul  9 2019 Thomas Blume <thomas.blume@suse.com>
- don't call systemd uninstall macro for clean-mount-point@.service
  template (boo#1139996)
* Thu Jun 13 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.8.3:
  + This release brings many memory leak fixes with similar work
    done in libblockdev-2.22. While libblockdev version requirement
    remains unchanged, it's strongly recommended to use both
    releases together to get full coverage of the fixes.
  + Other notable changes include:
  - Default and supported encryption types are now exposed on the
    org.freedesktop.UDisks2.Manager interface.
  - Minor org.freedesktop.UDisks2.Filesystem improvements related
    to updating properties upon method call return.
  - Various test fixes and improvements.
  - Updated translations.
* Wed Mar 20 2019 ro@suse.de
- update to 2.8.2
  + migration from intltool to gettext, udisks no longer depends
    on gnome-common
  + added 'windows_names' as a default mount option for ntfs-3g
  + fixed an issue potentially leading to open filedescriptors
    exhaustion
- drop buildreq for intltool
* Wed Feb 13 2019 Jan Engelhardt <jengelh@inai.de>
- Generalize VDO description.
- Fix faulty grammar.
* Tue Feb 12 2019 bjorn.lie@gmail.com
- Add more info to description of vdo.
* Wed Jan 30 2019 bjorn.lie@gmail.com
- Add libblockdev-vdo-devel BuildRequires: Build the new vdo
  module. Following this, add new vdo sub-package.
* Thu Jan 24 2019 bjorn.lie@gmail.com
- Update to version 2.8.1:
  + Mostly bugfixes.
- Changes from version 2.8.0:
  + Introduce a new VDO module that is built on top of
    libblockdev-vdo.
  + General bugfixes.
  + Support creating LUKS 2 encrypted devices and other
    LUKS-related enhancements.
* Thu Jan 24 2019 bjorn.lie@gmail.com
- Add explicit libblockdev-lvm-dbus-devel BuildRequires: Previously
  pulled in implicitly.
* Fri Jan 11 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.7.8:
  + Fix string format vulnerability (CVE-2018-17336)
* Wed Apr 25 2018 luc14n0@linuxmail.org
- Add missing libblockdev-loop Requires tag: it is needed by
  default.
* Wed Mar 28 2018 luc14n0@linuxmail.org
- Require specific libblockdev plugins in due udisks2's modules,
  following libblockdev's plugins split (bsc#1086447).
- Drop redundant libblockdev-devel BuildRequires: it is not needed
  once its pkgconfig module is already a requirement.
* Tue Mar  6 2018 luc14n0@linuxmail.org
- Fix BuildRequires/Requires tags related to libblockdev and
  libatasmart dependencies.
- Drop storaged Provides tags since there is no need for them.
- Switch libconfig-devel and libstoragemgmt-devel BuildRequires by
  their pkgconfig modules counterparts.
- Add a Recommends tag for the btrfs module to offer support for
  the openSUSE's file system of choice by default.
* Thu Mar  1 2018 jengelh@inai.de
- Rectify grammar issues in summaries
* Fri Nov 17 2017 luc14n0@linuxmail.org
- Update to version 2.7.6:
  + Add: UdisksUtabEntry and read-write lock.
  + Fix escaping mountpoint for the cleanup service.
  + Check for all LUKS devices when looking for
    CryptoBackingDevice.
  + First implementation of udisksutabmonitor.
  + Invoke job_complete in the proper context in order to avoid
    deadlocks.
  + Generate autocleanup functions for interfaces.
  + Update documentation.
- Changes from version 2.7.5:
  + Add:
  - 'no-discard' option to formatting methods.
  - An assertion method for checking an objects interfaces.
  + Fix:
  - Possible NULL pointer dereference in:
    udiskslinuxdrive.c, udiskslinuxmdraidobject.c and
    udisksclient.c
  - Resource leak.
  - size_str memory leaks in UDisksObjectInfo.
  - Copy-paste error in apply_configuration_thread_func from
    udiskslinuxdriveata.c.
  - "Deadcode" and ignore "check return" warnings in udisksctl.c.
  + Resolve mountpoint to the real path.
  + Include exFAT as a possible partition type for ID 0x07.
  + Always try to read configuration from crypttab in
    handle_unlock.
  + Make sure the table_type is consistent in
    handle_create_partition.
  + Wait for device to become initialized before probing it.
  + Use different mode/dmode for shared file systems.
- Changes from version 2.7.4:
  + Add: New function to set label on swap devices.
  + Fix:
  - Uninitalized value in "udisks_linux_loop_update";
  - Loop device automounting in GNOME.
  + Run cryptsetup before returning from non-blocking Format.
  + Use new libblockdev functionality to disable checks during
    init.
  + Do not try to create file watchers for RAIDs without
    redundancy.
  + Try to use libblockdev to get RAID array size.
  + Re-add support the legacy BIOS bootable GPT flag.
- Changes from version 2.7.3:
  + Add:
  - Version info to docstrings of the partition Resize function;
  - New ResolveDevice function;
  - New OpenDevice function;
  - some missing functions to doc/udisks2-sections.txt.in.in.
  + Fix:
  - Wrong GSList pointer declaration in
    "handle_get_block_devices";
  - "supports_owners" flag for UDF;
  - ExFAT partition type;
  - Bash completion for udisksctl;
  - Force unmounting;
  - Building documentation with new gtk-doc.
  + Process partition resize update before return.
  + Wait for cleartext device object to disappear on Lock().
  + Ignore Asus Zendisk virtual CDROM and ZFS member partitions.
  + Set corrent part type/id and GUID for UDF formatted partitions.
  + Use LUKS specific partition ID and GUID.
  + Make iSCSI Login and Logout wait for DBus objects update.
  + Disable cleaning using blivet for now.
  + Start even if a libblockdev plugin fails to load.
- Changes from version 2.7.2:
  + Add:
  - Filesystem Resize, Check and Repair;
  - A new "Partitions" property to "PartitionTable" interface;
  - A function to:
    . "take ownership" of a filesystem;
    . List all block devices.
  - A function to wait for an object to disappear.
  + Fix:
  - Detection of drives created using isohybrid images
    (fdo#1437791);
  - Setting "SetupByUID" property when adding a new loop device;
  - How we create UDF file systems.
  + Wait for:
  - The bcache object to disappear after BcacheDestroy;
  - Zram objects to disappear on DestroyDevices().
  + Resize method for Partition interface.
  + Trigger change uevent on disk after adding partitions to it.
  + Use the assert with multiple tries for Block.Configuration.
  + Do not wait for partitions to appear after LoopSetup.
  + Try harder to ignore WD SmartWare virtual CDs.
- Changes from version 2.7.1:
  + Don't always fail on missing LibStorageMgmt support.
  + Fix:
  - Broken partition authorization code;
  - How UDisksClient filters property changes;
  - The position to wait for a partition to appear at.
  + Don't use serial as unique ID for drive objects.
  + udiskslinuxblockbcache.c: Fix uninitialized variable.
  + udisksiscsiutil.c: Correct strncpy lengths.
  + udiskslinuxiscsisessionobject.c: Correct precondition check.
  + lsm_linux_drive.c: Remove std_lsm_vol_data_free error case.
  + udiskslinuxvolumegroupobject.c: Remove variable shadow lvs_p.
  + udiskssimplejob.c: Allow NULL for message.
  + Re-create sysfs watchers for changed mdraid devices.
  + UDisksClient: Do not try remove changed_blacklist hash table in
    finalize.
  + Query methods for available utility binaries.
  + Clear GError after calling "bd_part_get_part_by_pos".
  + Use "model_serial" as unique ID for drive objects.
  + Add "--yes" arg when resizing filesystem with "lvresize".
  + Do not trigger extra uevents for newly created partitions.
  + Free the partition spec libblockdev gives us.
  + Allow the user to specify the partition type.
- Changes from version 2.7.0:
  + udisksdaemonutil.c: Fix GVariant resource leak.
  + Use libblockdev swap plugin for swapspace.
  + Use libblockdev FS plugin for mounting and unmounting devices.
  + Use libblockdev:
  - For:
    . Partitioning code;
    . Wiping newly created partitions;
    . LUKS operations.
  - To get LUKS UUID for LUKS open;
  - As a library not just the plugins;
  - MDRAID code and wipefs calls in MDRAID code.
  + Use libblockdev-lvm for:
  - LV and VG operations;
  - VolumeGroupCreate() too;
  - When updating VG on Poll() call.
  + Fix:
  - bd_reinit and g_clear_error calls in btrfs, zram and bcache;
  - Docstring of 'CreateSnapshot' method in '.Filesystem.BTRFS';
  - Requires and BuildRequires for libblockdev;
  - API for BcacheCreate function.
  + Add:
  - Libblockdev MDRAID and FS plugins to BuildRequires;
  - 'options' parameter do zRAM 'Refresh' function;
  - A function for running threaded jobs synchronously;
  - A new configure option --enable-available-modules.
  + Remove unused variables in handle_mdraid_create.
  + Create Job objects for partitioning related actions.
  + Change:
  - btrfs module API to be consistent with udisks core;
  - bcache properties do CamelCase;
  - ZRAM 'CreateDevices' function to return newly created;
  - zRAM properties to CamelCase.
  + Bcache, btrfs and zRAM modules: Handle invocations in threads.
  + Do not try to set GError over the top of a previous GError.
  + zRAM: Extract used CompAlgorithm as a single value.
    ZRAMs.
  + Move new partition start if overlaps with extended partition
    metadata.
  + Do not start threaded jobs automatically
  + Require and initialize the libblockdev-lvm plugin
  + Check that blockdev/lvm.h is available if LVM2 support
    requested.
  + Also create thin pools using libblockdev-lvm.
  + Get VGs with bd_lvm_vgs() run in a thread.
  + Update information about PVs, LVs and VGs using
    libblockdev-lvm.
  + Get rid of the udisks-lvm helper program.
  + Use:
  - Info for metadata LV when updating LV which has one;
  - Systemd-defined macros in the spec file template;
  - bd_lvm_vgreduce() instead of running 'vgreduce'.
  + REMOVE-ME: use the CLI-based libblockdev-lvm plugin.
  + Make sure we have the AX_CHECK_ENABLE_DEBUG macro.
  + Also check if libblockdev supports bcache.
  + Require 'udev' not 'systemd-udev'.
- Adopt the use of %%make_build and %%make_install while dropping
  deprecated use of raw commands, following the best practices.
- Pass disable-static to configure as static libs are enabled by
  default. And enable-bcache, enable-btrfs, enable-lsm,
  enable-lvm2, enable-lvmcache and enable-zram to enable new
  available features.
- Add blkid, blockdev, libsystemd and mount pkgconfig modules, and
  libbd_btrfs-devel, libbd_crypto-devel, libbd_fs-devel,
  libbd_kbd-devel, libbd_loop-devel, libbd_lvm-devel,
  libbd_mdraid-devel, libbd_part-devel, libbd_swap-devel,
  libconfig-devel, libstoragemgmt-devel, lvm2-devel BuildRequires
  as new dependencies.
- Add libblockdev, libbd_crypto, libbd_fs, libbd_loop,
  libbd_mdraid, libbd_part and libbd_swap Requires as new run time
  requirements.
- Add e2fsprogs, xfsprogs, and dosfstools Requires, being the first
  needed by mkfs.ext3, mkfs.ext3 and e2label. The second, by
  mkfs.xfs and xfs_admin. And the third, by mkfs.vfat.
- Add gio-unix-2.0 and gmodule-2.0 pkgconfig BuildRequires: note
  that they was already being pulled with pkgconfig(glib-2.0) and
  used, once they live in the same devel package.
- Drop pkgconfig(udev) BuildRequires: no longer needed.
- Replace libgudev-1_0-devel and pkgconfig(systemd) BuildRequires
  by gudev-1.0 and libsystemd, respectively.
- Add LGPL-2.0+ to the preamble License tag once the preamble
  License tag is used for the source RPM and binary RPM packages.
- Correct some subpackages LGPL-2.1+ License tags to LGPL-2.0+ as
  pointed by the COPYING and source files.
* Wed Jul  5 2017 Thomas.Blume@suse.com
- Update to version 2.6.5 (fate#323354)
  * switch to new maintained codestream at
    https://github.com/storaged-project/udisks
  * Detailed changelog in /usr/share/doc/packages/udisks2/NEWS
* Fri Dec  9 2016 dimstar@opensuse.org
- Update to version 2.1.8:
  + Allow NTFS mount option "big_writes".
  + Don't coldplug uninitilized udev devices.
  + Detect old (non-Pro) MemoryStick cards.
  + Lock the partition table while creating a new partition.
  + exfat: Drop umask=0077 default.
  + udisks2.service: Add KillSignal=SIGINT.
  + btrfs: Add support for changing label.
  + Updated translations.
- Replace pkgconfig(libsystemd-login) BuildRequires with
  pkgconfig(libsystemd): the two have been merged since
  systemd 209.
- Drop udisks2-Reread-partition-table-before-wiping.patch: fixed
  upstream.
* Fri Apr 15 2016 zaitor@opensuse.org
- Add udisks2-Reread-partition-table-before-wiping.patch: Reread
  partition table before wiping when creating new partitions
  (fdo#85477).
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Update to 2.1.7:
  + Allow disabling ACL.
  + udisksctl: Properly redirect stdout.
  + Catch bogus UUID changes of MDRAIDs.
  + Fix udiskctl help for glib 2.45.
  + udisks2.service.in: Add [Install] section.
  + Fix translator comments in udisksobjectinfo.c.
  + integration-test: Explicitly require UDisks 2.0 typelib.
  + integration-test: Fix wait_timeout/busy error messages.
  + integration-test: PEP-8 fixes.
  + integration-test: Fix Polkit.test_removable_fs.
  + test_polkitd.py: Fix race condition in waiting for test
    polkitd.
  + integration-test: Fix race condition in fake CD drive creation.
  + integration-test: Add timeout to readd_device().
  + Add support for read look-ahead ATA settings (fdo#92488).
- Add tarball signing.
- Change group to System/Daemons.
* Thu Jul  9 2015 zaitor@opensuse.org
- Update to version 2.1.6:
  + udev rules: Stop hardcoding sed path.
  + Fix crash on inaccessible RAID member "state" attribute.
  + UDF: Drop umask=0077 default.
  + Install udisksd into a libexecdir.
  + Fail before formatting if partition contains a partition table.
  + Fix udisks_daemon_util_file_set_contents() return value
    handling.
  + Remove deprecated g_io_scheduler_* calls.
  + integration-tests:
  - Settle while waiting for property change.
  - Don't fail if a SMART test was aborted.
  - Add a wrapper to write and flush stderr.
  + Don't ignore isohybrid udf filesystems.
  + Add support for creating f2fs filesystems.
  + Decide whether devices are on the same seat by uid, not pid.
  + UDisksSpawnedJob: Retrieve uid/gid info before forking.
* Fri Mar  6 2015 sor.alexei@meowr.ru
- Update to 2.1.5:
  * configure: stop using tmpl files for docs.
  * docs: include the annotation glossary.
  * Drop default [df]mask for VFAT and NTFS.
  * Drop unused goto label.
  * Fix crash in udisks_client_finalize().
  * Fix format string signedness warnings.
  * integration-tests: Don't assume ordering in mount-points
    property.
  * integration-test: Skip double mount check for NTFS.
  * integration-test: Stop requiring the build dependencies.
  * integration-test: Test fstab parsing.
  * Make UdisksClient.get_size_for_display() units translatable.
  * Provide fallback for systems without ACL support.
  * Recognize PARTUUID and PARTLABEL in fstab.
  * Support mounting in /media for FHS compatibility.
  * Update translations.
- Add recommended /usr/sbin/rcudisks2 service alias.
- Remove obsolete definitions.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 2.1.4:
  + Add GPT partition types from the Discoverable Partitions
    Specification.
  + Remove newly-added "Auto-enabled swap" GTP partition type.
  + Fine-tune GTP partitions some more.
  + Send SCSI SYNCHRONIZE CACHE before powering down a drive.
  + Fix buffer overflow in pick_word_at().
  + Add Intel Fast Flash Standby partition GPT type.
  + Skip password strength checks when changing LUKS passphrase.
  + Fix build with clang.
  + Revert "Fix standby timers".
  + integration-test:
  - Update for logind.
  - Fix code formatting.
  - sync file systems in sync().
  - integration-test: Drop sync_workaround, fix property testing.
  - integration-test: Better failure messages.
  - integration-test: Fix btrfs test.
  + Fix display ID for generic FAT.
  + Update obsolete gnome-common and automake macros.
  + build:
  - Use config-aux/ directory.
  - Enable gcc colors.
  + Drop obsolete g_type_init().
  + Drop obsolete polkit_unix_process_new().
  + Fix docs for SmartUpdate().
  + Hide Microsoft reserved partition.
  + Identify JetFlash Transcend drives as thumb drives.
  + Fix sorting of mount points.
  + Fix fallback media icons for nonremovable media.
  + Fix polkit auth string.
  + Hide DIAGS and IntelRST partitions.
  + Add a man page for umount.udisks2.
  + Support building against libsystemd library.
  + udisks: Change name for Intel SW RAID.
  + Use internal pm check for smart poll.
  + Fix standby timers.
  + Fix TOCTOU race when making directories.
  + Add missing #include.
  + Properly initialize all used variables.
  + udiskslinuxmanager.c: Don't use uninitialized wait_data struct.
  + Remove useless assignments.
  + udisks_linux_drive_object_uevent(): Handle null device.
  + Hide Windows Recovery Environment partitions.
  + Updated translations.
* Mon Mar 10 2014 pwieczorkiewicz@suse.com
- Update to version 2.1.3:
  + Identify SD Card Reader in ChromeBook Pixel
  + Send SCSI START STOP UNIT when powering down a drive
  + udisksctl: add power-off verb to power off drives
  + udisksctl: fix grammar
  + Prefer /dev/VG/LV for LVM2 volumes.
  + Fix buffer overflow in mount path parsing. If users have
    the possibility to create very long mount points, such as
    with FUSE, they could cause udisksd to crash, or even to
    run arbitrary code as root with specially crafted mount paths.
    (bnc#865854, CVE-2014-0004)
  + Use SECTOR_COUNT=1 when issuing ATA IDENTIFY COMMAND
  + Use reentrant version of getpwuid() for thread safety
  + udisks_daemon_util_get_caller_uid_sync(): Add missing goto
  + Fix crash when loop-deleting non-loop device
* Sun Feb 16 2014 zaitor@opensuse.org
- Update to version 2.1.2:
  + Add exfat mount options.
  + Hide more rescue partitions.
  + Build fails due to missing IT_PROG_INTLTOOL macro (fdo#67679).
  + Add exfat FS integration test.
  + Drop "david" user name from publish make rules.
  + Use dosfstools instead of mtools.
  + Add polkit authorization variables for removable media.
  + Fix crash when waiting for loop device.
- Drop udisks2-20131026-removable-devices-polkit-auth.patch: fixed
  upstream.
* Tue Dec 10 2013 pwieczorkiewicz@suse.com
- Added udisks2-20131026-removable-devices-polkit-auth.patch.
  It adds polkit authorization variables for removable media, which
  allow restricting or granting access to removable media based on
  its type using polkit authorization rules (fate#312966 fdo#72122).
* Sun Nov 24 2013 crrodriguez@opensuse.org
- define _udevrulesdir only if not already defined
- run %%udev_rules_update, if defined.
* Wed Aug 21 2013 dimstar@opensuse.org
- Update to version 2.1.1:
  + Properly identify firewire devices as non-system devices.
  + Identify Lexar Dual Slot USB 3.0 Reader Professional as a card
    reader.
  + Identify Transcend USB 3.0 Multi-Card reader as such.
  + Promote ZFS partition type to generic.
  + UDisksClient: Make it possible to get part desc based on the
    part table subtype.
  + Add ChromeOS partition types.
  + Use new SSD icon from g-i-t-e.
  + Identify Patriot Memory USB sticks as thumb drives.
  + Fix test for logind availability.
  + Fix hiding of "WD SmartWare" partitions.
  + integration-test: Fix for nonexisting /run/udev/rules.d/.
  + integration-test: For VFAT, ignore case for label comparison.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 2.1.0:
  + mdraid: Remove spurious argument for the format.
  + Support broken setups where ID_SERIAL is available but
    ID_SERIAL_SHORT is not.
  + Call the right D-Bus completion routines.
  + integration-test: Update for mkntfs.
  + Updated translations.
* Sun Mar  3 2013 hrvoje.senjan@gmail.com
- Update to version 2.0.92:
  + Fix out of source build - set xsltproc path.
  + Fold UDisksPersistentStore class into UDisksCleanup.
  + Rename UDisksCleanup to UDisksState.
  + Don't leak UDisksLinuxDevice when handling uevent.
  + Check for NULL pointer when creating MD-RAID array.
  + Use own udev namespace for MD-RAID properties.
  + Introduce UDISKS_FILESYSTEM_SHARED=1 to use /media for
    mounting.
  + Don't wipe extended partitions.
  + Make sure logical partitions stay within the extended
    partition.
* Thu Jan 17 2013 dimstar@opensuse.org
- Update to version 2.0.91:
  + Don't bail in MD-RAID file monitor event handler.
  + Add MDRaid:RequestSyncAction() method.
  + Add MDRaid:SyncRate and MDRaid:SyncRemainingTime properties.
  + Get the MD-RAID sync rate from the right file.
  + Pull new translations from Transifex.
  + Use correct polkit action.
  + Fix up comments in polkit policy file.
- Changes from version 2.0.90:
  + Initial MD-RAID support.
- Drop fix_polkit_action_name.diff: it's not applied anyway.
* Thu Jan 17 2013 vuntz@opensuse.org
- Really apply fix_polkit_action_name.diff.
* Mon Jan  7 2013 stefan.bruens@rwth-aachen.de
- Fix name of polkit action (fdo#58629):
  modify-device-system-other-seat -> modify-device-other-seat
* Sun Jan  6 2013 dimstar@opensuse.org
- Add gptfdisk Requires: sgdisk is called by udisksd to modify the
  partition tables (bnc#796853).
* Mon Nov 12 2012 hrvoje.senjan@gmail.com
- Update to version 2.0.0
  + configure.ac: raise gudev dependency
  + Add --disable-man configure option
  + Update list of recovery/system partitions
  + Add support for creating exFAT filesystems and changing exFAT
    labels
  + Add textual descriptions for IMSM Raid members
  + Use all-caps for RAID
  + Only do the isohybrid hack for the first partition
  + Don't complain about missing /etc/crypttab file
  + Don't complain about missing /etc/fstab file
  + Make it work without requiring the kernel to be CONFIG_SWAP=y
  + Mention the right file when complaing about /proc/swaps
  + Fix glaringly wrong documentation for Filesystem.Mount()
  + Move bash completion script into
    /usr/share/bash-completion/completions
  + Don't require that users define UDISKS_API_IS_SUBJECT_TO_CHANGE
  + Remove udisks_daemon_util_on_other_seat() from sections.txt
  + Add workaround annotation for
    udisks_client_get_block_for_dev()
  + Enable large file support
  + Various doc and tests fixes
  + Bugs fixed: fdo#51063.
  + Updated translations.
- Drop systemd-dynamic-check.diff: fixed upstream.
- Dropped gnome-common BuildRequires and call to gnome-autogen.sh,
  as the patch which needed that is dropped.
* Wed Oct 24 2012 meissner@suse.com
- remove the rpmlintrc after adding the privs bnc#779404
* Wed Oct 17 2012 fcrozat@suse.com
- Fix build with new udev rules directory location.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 1.99.0:
  + Catch up with latest polkit guidance
  + Don't require auth for Standby'ing non-system drives on own
    seat
  + Mark Realtek rts5229 based card readers as flash drives
  + Black-list seemingly invalid WWN for SAMSUNG SP1604N hard disks
  + Ignore non-Linux software on SanDisk Cruzer
  + Add drive configuration interfaces and configuration files
  + Add "Linux Filesystem" GPT partition type
  + Add support for VMWare filesystem types and GPT partition types
  + Update integration tests.
  + Bugs fixed:
  - fdo#51439: udisks should hide lvm PVs
- Changes from version 1.98.0:
  + Drive: Refuse to eject drives that appear to be in use
  + udisksd: work if polkitd is not available
  + Updated documentations
  + Bugs fixed:
  - fdo49842: Unhandled rootfs on bind mount
- Drop udisks-hide-lvm-raid-partitions.patch: fixed upstream.
* Tue Sep 25 2012 vuntz@opensuse.org
- Update systemd-dynamic-check.diff with patch sent upstream.
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  needed by the patch now.
* Tue Jul  3 2012 tiwai@suse.de
- Add systemd-dynamic-check.diff: add a check of running systemd
  (bnc#769570)
* Tue Jun 26 2012 gber@opensuse.org
- Added udisks-hide-lvm-raid-partitions.patch in order to hide
  partitions marked as containing LVM and RAID. This is only useful
  for encrypted partitions (fixes fdo#51439 and bnc#737038).
* Fri May 11 2012 vuntz@opensuse.org
- Update to version 1.97.0:
  + Several improvements for loop devices
  + Also check for "target is busy" when checking umount(8) output
  + UDisksCleanup: Remove stale entries when adding new ones
  + Add work-around to show FS on CDs/USB sticks created using
    isohybrid
  + Several code improvements
  + Update path to mounted-fs file in documentation
- Changes from version 1.96.0:
  + Actually link with libsystemd-login
- Changes from version 1.95.0:
  + Add multi-seat support
  + Add versioning macros
  + Use libacl library instead of setfacl(1)
  + Work around missing serial/wwn on VMware hard disks
  + Add separate polkit actions for ejecting media
  + Make $(udisks2.device) in authentication messages include the
    vendor/model
  + Remove unused .filesystem-unmount-others-shared polkit action
  + Documentation fixes and improvements
  + Updated translations
- Add libacl-devel BuildRequires: it's now really used.
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 1.94.0:
  + Pass --readonly to cryptsetup(8) if device to unlock is
    read-only
  + Add udev rules for identifying devices which should not be
    shown
  + Fix unmounting large disks when not asked to
  + Make escaping work properly with non-ASCII UTF-8 strings
  + Change some D-Bus types from bytestring ('ay') to UTF8 ('s')
  + Convert some g_warning() uses to udisks_warning()
  + Improved documentation.
* Tue Mar  6 2012 vuntz@opensuse.org
- Update to version 1.93.0:
  + Force MediaRemovable to TRUE for e.g. SD cards using the mmc
    layer
  + Ensure that whatever we pass as -t to mount(8) is in a
    whitelist
  + Ensure that the loop file name we pass to the kernel is always
    NUL-terminated
  + Properly escape all device files
  + Improved documentation.
- Remove libacl-devel BuildRequires: not needed anymore.
* Mon Feb 27 2012 vuntz@opensuse.org
- Update to version 1.92.0:
  + client: Fix bit shifts of flags on 32 bit
  + Avoid using $XDG_RUNTIME_DIR/media for now
  + Don't free object twice when deleting a loop device
  + Use /run/media/$USER for mounting
  + Move to /usr-only setup and get rid of hardcoded paths to /lib
    and sbin
- Changes from version 1.91.0:
  + Install a systemd service file if systemd is used
  + Ensure PATH is set
  + Fix use of memset(3)
  + Use org.freedesktop.UDisks2.* for errors, not
    org.freedesktop.UDisks.*
  + For mount options, switch from comment=udisks to x-udisks
  + Prefer mounting in /run/user/$USER/media instead of /media
  + With /media and /run on tmfs, switch to temporary store for
    mounted-fs
  + Make sure that Drive:SortKey sorts e.g. sdz before sdaa
  + Do coldplug for block devices twice
  + Use g_dbus_interface_dup_object() and check return value
  + Shut up valgrind complaing about LOOP_GET_STATUS64 ioctl
  + Fix a couple of uninitialized warnings and simplify SMART
    self-test handling
  + udisksctl:
  - nuke PORT column in output of 'status' verb
  - sort the drives using Drive:SortKey for 'status' verb
  + Documentation fixes.
  + Build fixes.
  + Updated translations.
- Add systemd-related packaging:
  + Add pkgconfig(systemd) BuildRequires.
  + Use %%{?systemd_requires}.
  + Call %%service_{add,del}_* macros in scriptlets for
    udisks2.service.
- Add pkgconfig(udev) BuildRequires, now needed to find right path
  for udev files.
- Add libacl-devel BuildRequires, now needed.
* Sat Jan 21 2012 vuntz@opensuse.org
- New udisks2 source package, based on udisks source package.
- First version (1.90.0).
- udisks 2.x is parallel-installable with udisks 1.x.
